pub struct GrpcReplicaFactory { /* private fields */ }Expand description
Reusable Google Storage v2 channel, authentication handle, and zonal routing token for one Rapid bucket.
Implementations
Sourceimpl GrpcReplicaFactory
impl GrpcReplicaFactory
Sourcepub async fn connect(
zone: usize,
endpoint: &str,
bucket: impl Into<String>,
bearer_token: Option<String>,
) -> Result<Self, Error>
pub async fn connect( zone: usize, endpoint: &str, bucket: impl Into<String>, bearer_token: Option<String>, ) -> Result<Self, Error>
Connect a zonal bucket with an optional static bearer token.
The bucket must be a full v2 resource name such as
projects/_/buckets/example-zone-a. All replicas created by the factory
share the routing token learned from zonal write redirects. The normal
production endpoint is https://storage.googleapis.com; Cloud Storage
regional JSON/XML endpoints do not support this gRPC client.
Sourcepub fn from_channel(
zone: usize,
channel: Channel,
bucket: impl Into<String>,
bearer_token: Option<String>,
) -> Self
pub fn from_channel( zone: usize, channel: Channel, bucket: impl Into<String>, bearer_token: Option<String>, ) -> Self
Build a factory over an already-established channel. The deterministic
simulator uses this to route the production client over a simulated
transport (Endpoint::connect_with_connector); production callers use
connect/connect_with_auth.
Sourcepub async fn connect_with_auth(
zone: usize,
endpoint: &str,
bucket: impl Into<String>,
auth: BearerAuth,
) -> Result<Self, Error>
pub async fn connect_with_auth( zone: usize, endpoint: &str, bucket: impl Into<String>, auth: BearerAuth, ) -> Result<Self, Error>
Connect a zonal bucket using a shared static or refreshing auth handle.
Cloned refreshing handles update existing clients through ArcSwap.
Use full v2 bucket resource names and a gRPC-compatible endpoint such as
https://storage.googleapis.com.